$wnd.rstudio.runAsyncCallback15("function J1p(){}\nfunction c1p(a){this.a=a}\nfunction H1p(a){this.a=a}\nfunction M1p(a){this.a=a}\nfunction O1p(a){this.a=a}\nfunction S2p(a){this.a=a}\nfunction Gyi(a){this.a=a}\nfunction a1p(a){Tci.call(this,a)}\nfunction J0p(a){V0p(a,new M1p(a))}\nfunction P0p(a){a.J.r4b();en((Zm(),Ym),new c1p(a))}\nfunction O0p(a){cxi(a.b,D0p.f5b(),D0p.f5b(),new O1p(a))}\nfunction Q0p(a){Yet(a.n,new C1p(a,rYx,false),new E1p,uCy)}\nfunction N0p(a){Yet(a.n,new H1p(a),new J1p,D0p.$4b())}\nfunction S0p(a,b){rPh(a.d,new OCq(b,true,true),false)}\nfunction nxi(a,b){zwi();(YGe(b),b)&&U0p(a.a,ZXA,'')}\nfunction e1p(a,b){jlf();this.a=a;this.b=b;llf.call(this)}\nfunction L1p(a,b){S0p(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction Y2l(a,b){K7l(a,Kty,'devtools_load_all_path',new uL,b)}\nfunction V0p(a,b){a.c!=null?L1p(b,a.c):Y2l(a.j,new e1p(a,b))}\nfunction cxi(a,b,c,d){Pwi(a,b,c,fzi(qqo(a.i.b),'roxygen'),Cwi(a,'roxygen'),false,new Gyi(d))}\nfunction G0p(a,b){var c,d;npi(a.q.g,null);d=b.outputs;for(c=0;c<d.length;c++)__p(a.q,d[c]);b.errors.length>0&&$_p(a.q,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?g0e(a.a.Vj,true,false):mpi(a.q.g);xHg(a.q.g.c.c)}\nfunction O2p(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=c5p(a.a.b.a);sOp(a.a,a.a.a)}switch(a.c){case 1:G0p(a.a.a,a.b[0]);break;case 2:a.a.a.J.p4b();break;case 3:a.a.a.J.q4b();break;case 4:U0p(a.a.a,E7z,'');break;case 5:U0p(a.a.a,'build-binary-package','');break;case 6:U0p(a.a.a,'build-full','');break;case 7:U0p(a.a.a,'build-incremental','');break;case 8:U0p(a.a.a,'build-source-package','');break;case 9:U0p(a.a.a,'check-package','');break;case 10:U0p(a.a.a,'clean-all','');break;case 11:N0p(a.a.a);break;case 12:O0p(a.a.a);break;case 13:P0p(a.a.a);break;case 14:Q0p(a.a.a);break;case 15:N8l(a.a.a.j,new a1p((E0p(),D0p).q5b()));break;case 16:U0p(a.a.a,'test-package','');break;case 19:a.a.a.J.s4b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar ZXA='roxygenize-package',$XA='Error Terminating Build',_XA='Unable to terminate build. Please try again.',aYA='Building package documentation',bYA='Terminating Build...';sFd(2288,1,jTx,Gyi);_.jw=function Hyi(a){nxi(this.a,a)};var bwb=dse(2288);sFd(7908,381,{},a1p);_.$m=function b1p(a){(YGe(a),a)||fci(3,(E0p(),D0p).b5b(),D0p.c5b()).HT()};var $cc=dse(7908);sFd(7909,1,oTx,c1p);_.ln=function d1p(){xHg(this.a.q.g.c.c)};var _cc=dse(7909);sFd(7910,53,{},e1p);_.oA=function f1p(a){this.a.c=a;L1p(this.b,this.a.c)};var adc=dse(7910);sFd(7901,1,oTx,H1p);_.ln=function I1p(){J0p(this.a)};var qdc=dse(7901);sFd(7902,1,oTx,J1p);_.ln=function K1p(){E0p()};var rdc=dse(7902);sFd(7900,1,jTx,M1p);_.jw=function N1p(a){L1p(this,a)};var sdc=dse(7900);sFd(7903,1,oTx,O1p);_.ln=function P1p(){U0p(this.a,ZXA,'')};var tdc=dse(7903);sFd(246,1,Kqy);_.jn=function R2p(){O2p((new S2p(this)).a)};sFd(7206,1,oTx,S2p);_.ln=function T2p(){O2p(this.a)};var Qdc=dse(7206);sFd(5467,1,H7z);_.b5b=function d3p(){return $XA};_.c5b=function e3p(){return _XA};_.f5b=function h3p(){return aYA};_.q5b=function s3p(){return bYA};sFd(5466,1,H7z);_.b5b=function E3p(){return $XA};_.c5b=function F3p(){return _XA};_.f5b=function I3p(){return aYA};_.q5b=function T3p(){return bYA};sFd(5465,1,H7z);_.b5b=function d4p(){return 'Erreur de fin de construction'};_.c5b=function e4p(){return 'Impossible de terminer la construction. Veuillez r\\xE9essayer.'};_.f5b=function h4p(){return 'Documentation du paquet de construction'};_.q5b=function s4p(){return 'Terminer la construction...'};lDx(fm)(15);\n//# sourceURL=rstudio-15.js\n")
