/*
 *  /MathJax/localization/sv/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("sv","FontWarnings",{version:"2.7.6",isLoaded:true,strings:{webFont:"MathJax anv\u00E4nder webb-baserade teckensnitt f\u00F6r att visa matematik p\u00E5 denna sida.  Dessa tar tid att ladda ner, sidan skulle g\u00F6ra snabbare om du installerar matematik-typsnitt direkt i systemets teckensnittsmapp.",imageFonts:"MathJax anv\u00E4nder sina bild-teckensnitt ist\u00E4llet f\u00F6r lokala eller webb-baserade typsnitt. Detta kommer att g\u00F6ra visningen saktare \u00E4n vanligt, matematik kan \u00E4ven komma att inte skrivas ut med din skrivares fulla uppl\u00F6sning.",noFonts:"MathJax kan inte hitta ett typsnitt f\u00F6r att visa sin matematik, och bild-teckensnitt \u00E4r ej tillg\u00E4ngliga, s\u00E5 den faller tillbaka p\u00E5 generiska Unicode-tecken i hopp om att din webbl\u00E4sare kommer att kunna visa dem. Vissa tecken kan komma att visas inkorrekt, eller kanske inte alls.",webFonts:"De flesta moderna webbl\u00E4sare till\u00E5ter teckensnitt att h\u00E4mtas via webben. Att uppdatera till en nyare version av din webbl\u00E4sare (eller byta webbl\u00E4sare) kan f\u00F6rb\u00E4ttra kvaliteten p\u00E5 matematik p\u00E5 denna sida.",fonts:"MathJax kan antingen anv\u00E4nda [STIX-typsnitt](%1) eller [MathJax TeX-typsnitt](%2). Ladda ner och installera en av dessa typsnitt f\u00F6r att f\u00F6rb\u00E4ttra din MathJax-upplevelse.",STIXPage:"Denna sida \u00E4r designad f\u00F6r att anv\u00E4nda [STIX-typsnitt](%1). Ladda ner och installera dessa typsnitt f\u00F6r att f\u00F6rb\u00E4ttra din MathJax-upplevelse.",TeXPage:"Denna sida \u00E4r designad f\u00F6r att anv\u00E4nda [MathJax TeX-typsnitt](%1). Ladda ner och installera dessa typsnitt f\u00F6r att f\u00F6rb\u00E4ttra din MathJax-upplevelse."}});MathJax.Ajax.loadComplete("[MathJax]/localization/sv/FontWarnings.js");
